Actions, Resources, and Condition Keys for AWS CodeDeploy - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodeDeploy.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for AWS CodeDeploy

AWS CodeDeploy (service prefix: `codedeploy`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS CodeDeploy
- Resources Defined by AWS CodeDeploy
- Condition Keys for AWS CodeDeploy

## Actions Defined by AWS CodeDeploy

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AddTagsToOnPremisesInstances | Add tags to one or more on-premises instances. | Tagging | instance* |  |
BatchGetApplicationRevisions | Gets information about one or more application revisions. | Read | application* |  |
BatchGetApplications | Get information about multiple applications associated with the IAM user. | Read | application* |  |
BatchGetDeploymentGroups | Get information about one or more deployment groups. | Read | deploymentgroup* |  |
BatchGetDeploymentInstances | Gets information about one or more instance that are part of a deployment group. | Read | deploymentgroup* |  |
BatchGetDeployments | Get information about multiple deployments associated with the IAM user. | Read | deploymentgroup* |  |
BatchGetOnPremisesInstances | Get information about one or more on-premises instances. | Read | instance* |  |
ContinueDeployment | Starts the process of rerouting traffic from instances in the original environment to instances in thereplacement environment without waiting for a specified wait time to elapse. | Write |  |  |
CreateApplication | Create an application associated with the IAM user. | Write | application* |  |
CreateDeployment | Create a deployment for an application associated with the IAM user. | Write | deploymentgroup* |  |
CreateDeploymentConfig | Create a custom deployment configuration associated with the IAM user. | Write | deploymentconfig* |  |
CreateDeploymentGroup | Create a deployment group for an application associated with the IAM user. | Write | deploymentgroup* |  |
DeleteApplication | Delete an application associated with the IAM user. | Write | application* |  |
DeleteDeploymentConfig | Delete a custom deployment configuration associated with the IAM user. | Write | deploymentconfig* |  |
DeleteDeploymentGroup | Delete a deployment group for an application associated with the IAM user. | Write | deploymentgroup* |  |
DeregisterOnPremisesInstance | Deregister an on-premises instance. | Write | instance* |  |
GetApplication | Get information about a single application associated with the IAM user. | List | application* |  |
GetApplicationRevision | Get information about a single application revision for an application associated with the IAM user. | List | application* |  |
GetDeployment | Get information about a single deployment to a deployment group for an application associated with the IAM user. | List | deploymentgroup* |  |
GetDeploymentConfig | Get information about a single deployment configuration associated with the IAM user. | List | deploymentconfig* |  |
GetDeploymentGroup | Get information about a single deployment group for an application associated with the IAM user. | List | deploymentgroup* |  |
GetDeploymentInstance | Get information about a single instance in a deployment associated with the IAM user. | List | deploymentgroup* |  |
GetOnPremisesInstance | Get information about a single on-premises instance. | List | instance* |  |
ListApplicationRevisions | Get information about all application revisions for an application associated with the IAM user. | List | application* |  |
ListApplications | Get information about all applications associated with the IAM user. | List |  |  |
ListDeploymentConfigs | Get information about all deployment configurations associated with the IAM user. | List |  |  |
ListDeploymentGroups | Get information about all deployment groups for an application associated with the IAM user. | List | application* |  |
ListDeploymentInstances | Get information about all instances in a deployment associated with the IAM user. | List | deploymentgroup* |  |
ListDeployments | Get information about all deployments to a deployment group associated with the IAM user, or to get all deployments associated with the IAM user. | List | deploymentgroup* |  |
ListOnPremisesInstances | Get a list of one or more on-premises instance names. | List |  |  |
PutLifecycleEventHookExecutionStatus | Notify a lifecycle event hook execution status for associated deployment with the IAM user. | Write |  |  |
RegisterApplicationRevision | Register information about an application revision for an application associated with the IAM user. | Write | application* |  |
RegisterOnPremisesInstance | Register an on-premises instance. | Write | instance* |  |
RemoveTagsFromOnPremisesInstances | Remove tags from one or more on-premises instances. | Tagging | instance* |  |
StopDeployment | Description for StopDeployment | Write |  |  |
UpdateApplication | Description for UpdateApplication | Write | application* |  |
UpdateDeploymentGroup | Change information about a single deployment group for an application associated with the IAM user. | Write | deploymentgroup* |  |

## Resources Defined by AWS CodeDeploy

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
application | `arn:${Partition}:codedeploy:${Region}:${Account}:application:${ApplicationName}` |
deploymentconfig | `arn:${Partition}:codedeploy:${Region}:${Account}:deploymentconfig:${DeploymentConfigurationName}` |
deploymentgroup | `arn:${Partition}:codedeploy:${Region}:${Account}:deploymentgroup:${ApplicationName}/${DeploymentGroupName}` |
instance | `arn:${Partition}:codedeploy:${Region}:${Account}:instance:${InstanceName}` |

## Condition Keys for AWS CodeDeploy

CodeDeploy has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by AWS CodeDeploy
- Resources Defined by AWS CodeDeploy
- Condition Keys for AWS CodeDeploy

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more